@@ -3,7 +3,9 @@ from ._conformers import cluster
 from ._conformers import rmsd
 from ._conformers import return_centroids
 from ._conformers import translate
+from ._conformers import align_conformers
 
 from ._features import sasa
 from ._features import get_coords
 from ._features import center_of_mass
+from ._features import keep_conformers
